package org.apache.commons.lang3;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.Serializable;
import java.util.Iterator;
import org.apache.commons.lang3.Validate;

final class CharRange implements Iterable<Character>, Serializable {
  private static final long serialVersionUID = 8270183163158333422L;
  
  private final char start;
  
  private final char end;
  
  private final boolean negated;
  
  private transient String iToString;
  
  static final org.apache.commons.lang3.CharRange[] EMPTY_ARRAY = new org.apache.commons.lang3.CharRange[0];
  
  private CharRange(char start, char end, boolean negated) {
    if (start > end) {
      char temp = start;
      start = end;
      end = temp;
    } 
    this.start = start;
    this.end = end;
    this.negated = negated;
  }
  
  public static org.apache.commons.lang3.CharRange is(char ch) {
    return new org.apache.commons.lang3.CharRange(ch, ch, false);
  }
  
  public static org.apache.commons.lang3.CharRange isNot(char ch) {
    return new org.apache.commons.lang3.CharRange(ch, ch, true);
  }
  
  public static org.apache.commons.lang3.CharRange isIn(char start, char end) {
    return new org.apache.commons.lang3.CharRange(start, end, false);
  }
  
  public static org.apache.commons.lang3.CharRange isNotIn(char start, char end) {
    return new org.apache.commons.lang3.CharRange(start, end, true);
  }
  
  public char getStart() {
    return this.start;
  }
  
  public char getEnd() {
    return this.end;
  }
  
  public boolean isNegated() {
    return this.negated;
  }
  
  public boolean contains(char ch) {
    return (((ch >= this.start && ch <= this.end)) != this.negated);
  }
  
  public boolean contains(org.apache.commons.lang3.CharRange range) {
    Validate.notNull(range, "range", new Object[0]);
    if (this.negated) {
      if (range.negated)
        return (this.start >= range.start && this.end <= range.end); 
      return (range.end < this.start || range.start > this.end);
    } 
    if (range.negated)
      return (this.start == '\000' && this.end == Character.MAX_VALUE); 
    return (this.start <= range.start && this.end >= range.end);
  }
  
  public boolean equals(Object obj) {
    if (obj == this)
      return true; 
    if (!(obj instanceof org.apache.commons.lang3.CharRange))
      return false; 
    org.apache.commons.lang3.CharRange other = (org.apache.commons.lang3.CharRange)obj;
    return (this.start == other.start && this.end == other.end && this.negated == other.negated);
  }
  
  public int hashCode() {
    return 83 + this.start + 7 * this.end + (this.negated ? 1 : 0);
  }
  
  public String toString() {
    if (this.iToString == null) {
      StringBuilder buf = new StringBuilder(4);
      if (isNegated())
        buf.append('^'); 
      buf.append(this.start);
      if (this.start != this.end) {
        buf.append('-');
        buf.append(this.end);
      } 
      this.iToString = buf.toString();
    } 
    return this.iToString;
  }
  
  public Iterator<Character> iterator() {
    return new CharacterIterator(this, null);
  }
}
